
; The GUI include file
;
; Version 1.0 - Last Update 8/15/02
; By Geoff Lywood aka KrYpT


.nolist
; Note that most things are in app-ready form. Just uncomment
; the next line if you get a lot of error messages.
;#define EQU .equ

; ------ MACROS ------
; All GUI routines are accessed using the gcall macro. This is similar
; to the way system routines use the bcall macro, only specifically
; designed to run GUI routines. Sorry, it's a full five bytes, but
; there's nothing I can do about that.
;
#define gcall(label) call $812B \ .dw label

; If you're making an app, use the macros below. (upper/lower case are provided)
;G_CALL macro   label
;	     CALL     812Bh
;	     DW       &label
;       .endm
;
;g_call macro   label
;	     call     812Bh
;	     dw       &label
;       .endm



; ------ VERSIONS ------
; I'm using a bit of a wierd numbering system for this, where all versions
; are assigned a single byte number (not major/minor).
; These are used as comparators for the result of guiVersion, or as "inputs"
; for guiInit (see loadgui.asm for details).
;
GUI_VERSION_01		EQU	1
GUI_VERSION_02		EQU	2		; Fixed guiDrawSprite (now it works)


; ------ ROUTINES ------
; These are all fully documented in the LibSpecs.htm file.
;
guiInitialize		EQU	4083h		; Initialize GUI
guiVersion		EQU	4086h		; Get GUI version.
guiMultiLineTextL	EQU	4089h		; Left aligned multiple lines of text
guiMultiLineTextC	EQU	408Ch		; Center aligned multiple lines of text
guiCenterText		EQU	408Fh		; Center aligned string
guiNextStr		EQU	4092h		; Skip to the next string
guiMessageBox		EQU	4095h		; Standard Message Box
guiMessageBoxEX		EQU	4098h		; Message Box with extra options
guiOptionBox		EQU	409Bh		; Standard Option Box
guiOptionBoxEX		EQU	409Eh		; Option Box with extra options
guiInputBox		EQU	40A1h		; Standard Input Box
guiInputBoxEX		EQU	40A4h		; Input Box with extra options
guiStringInput		EQU	40A7h		; Input a string (register input)
guiStringInputST	EQU	40AAh		; Input a string (structure input)
guiWindow		EQU	40ADh		; Box with title
guiWindowEX		EQU	40B0h		; Box with title and extra options
guiMenu			EQU	40B3h		; Standard Menu
guiMenuEX		EQU	40B6h		; Menu with extra options.

guiDrawForm		EQU	40B9h		; Draw a form
guiShowForm		EQU	40BCh		; Show a form
guiHideForm		EQU	40BFh		; Hide a form
guiDrawLabel		EQU	40C2h		; Draw a label
guiShowLabel		EQU	40C5h		; Show a label
guiHideLabel		EQU	40C8h		; Hide a label
guiDrawPara		EQU	40CBh		; Draw a paragraph
guiShowPara		EQU	40CEh		; Show a paragraph
guiHidePara		EQU	40D1h		; Hide a paragraph
guiDrawButton		EQU	40D4h		; Draw a button
guiShowButton		EQU	40D7h		; Show a button
guiHideButton		EQU	40DAh		; Hide a button
guiDrawCheckBox		EQU	40DDh		; Draw a checkbox
guiShowCheckBox		EQU	40E0h		; Show a checkbox
guiHideCheckBox		EQU	40E3h		; Hide a checkbox
guiCheckCheckBox	EQU	40E6h		; Check a checkbox
guiUnCheckBox		EQU	40E9h		; Uncheck a checkbox
guiDrawOptions		EQU	40ECh		; Draw some options
guiShowOptions		EQU	40EFh		; Show some options
guiHideOptions		EQU	40F2h		; Hide some options
guiSetOption  		EQU	40F5h		; Set a current option
guiDrawTextBox		EQU	40F8h		; Draw a textbox
guiShowTextBox		EQU	40FBh		; Show a textbox
guiHideTextBox		EQU	40FEh		; Hide a textbox
guiInputTextBox		EQU	4101h		; Input text to a textbox
guiDrawBitmap		EQU	4104h		; Draw a bitmap
guiDrawList		EQU	4107h		; Draw a list
guiShowList		EQU	410Ah		; Show a list
guiHideList		EQU	410Dh		; Hide a list
guiSetList		EQU	4110h		; Set the list selection
guiDrawDrop		EQU	4113h		; Draw a droplist
guiShowDrop		EQU	4116h		; Show a droplist
guiHideDrop		EQU	4119h		; Hide a droplist
guiSetupMouse		EQU	411Ch		; Initialize mouse variables
guiHandleMouse		EQU	411Fh		; Handle mouse motion
guiHandleClick		EQU	4122h		; Handle a mouse click
guiDrawSprite		EQU	4125h		; Draw a sprite (bitmap with reg input)


; ------ FLAGS ------
; Another wierd system... The actual flag number is obtained by adding the letters "RF"
; to the flag you want, and without the "RF" is a number with that bit set. This is to
; simplify the manual production of GUI objects, letting you just add equates. For example:
; .db MB_Buffer+MB_BigTitle+MB_TitleCenter+MB_Waitkey
; would be a perfectly functional flag byte in a MessageBoxEX structure.
;

; MessageBoxEX Flags
MB_BufferRF		EQU	0
MB_CenterTitleRF	EQU	1
MB_CenterTextRF		EQU	2
MB_BigTitleRF		EQU	3
MB_BigTextRF		EQU	4
MB_DelayRF		EQU	5
MB_WaitkeyRF		EQU	6
MB_AnimateRF		EQU	7

MB_Buffer		EQU	1<<MB_BufferRF
MB_CenterTitle		EQU	1<<MB_CenterTitleRF
MB_CenterText		EQU	1<<MB_CenterTextRF
MB_BigTitle		EQU	1<<MB_BigTitleRF
MB_BigText		EQU	1<<MB_BigTextRF
MB_Delay		EQU	1<<MB_DelayRF
MB_Waitkey		EQU	1<<MB_WaitkeyRF
MB_Animate		EQU	1<<MB_AnimateRF

; OptionBoxEX Flags
OB_BufferRF		EQU	0
OB_CenterTitleRF	EQU	1
OB_CenterTextRF		EQU	2
OB_CustomTextRF		EQU	3
OB_BigTitleRF		EQU	4
OB_BigTextRF		EQU	5
OB_BigChoicesRF		EQU	6
OB_UpDownOnlyRF		EQU	7

OB_Buffer		EQU	1<<OB_BufferRF
OB_CenterTitle		EQU	1<<OB_CenterTitleRF
OB_CenterText		EQU	1<<OB_CenterTextRF
OB_CustomText		EQU	1<<OB_CustomTextRF
OB_BigTitle		EQU	1<<OB_BigTitleRF
OB_BigText		EQU	1<<OB_BigTextRF
OB_BigChoices		EQU	1<<OB_BigChoicesRF
OB_UpDownOnly		EQU	1<<OB_UpDownOnlyRF

; InputBoxEX Flags
IB_BufferRF		EQU	0
IB_CenterTitleRF	EQU	1
IB_CenterTextRF		EQU	2
IB_BigTitleRF		EQU	3
IB_BigTextRF		EQU	4
IB_CustomTextRF		EQU	5

IB_Buffer		EQU	1<<IB_BufferRF
IB_CenterTitle		EQU	1<<IB_CenterTitleRF
IB_CenterText		EQU	1<<IB_CenterTextRF
IB_BigTitle		EQU	1<<IB_BigTitleRF
IB_BigText		EQU	1<<IB_BigTextRF
IB_CustomText		EQU	1<<IB_CustomTextRF

; StringInput Flags

SI_BigFontRF		EQU	0
SI_NoCursorRF		EQU	1
SI_NoDispRF		EQU	2
SI_NumbersDefRF		EQU	3
SI_NoAlphaRF		EQU	4
SI_NoClearDelRF		EQU	5
SI_NullAllowedRF	EQU	6
SI_UseDefaultRF		EQU	7

SI_BigFont		EQU	1<<SI_BigFontRF
SI_NoCursor		EQU	1<<SI_NoCursorRF
SI_NoDisp		EQU	1<<SI_NoDispRF
SI_NumbersDef		EQU	1<<SI_NumbersDefRF
SI_NoAlpha		EQU	1<<SI_NoAlphaRF
SI_NoClearDel		EQU	1<<SI_NoClearDelRF
SI_NullAllowed		EQU	1<<SI_NullAllowedRF
SI_UseDefault		EQU	1<<SI_UseDefaultRF

; WindowEX Flags
WI_BufferRF		EQU	0
WI_CenterTitleRF	EQU	1
WI_BigTitleRF		EQU	2

WI_Buffer		EQU	1<<WI_BufferRF
WI_CenterTitle		EQU	1<<WI_CenterTitleRF
WI_BigTitle		EQU	1<<WI_BigTitleRF

; MenuEX Flags
ME_BufferRF		EQU	0
ME_CenterTitleRF	EQU	1
ME_BigTitleRF		EQU	2
ME_BigTextRF		EQU	3
ME_CustomTextRF		EQU	4
ME_ClearQuitRF		EQU	5

ME_Buffer		EQU	1<<ME_BufferRF
ME_CenterTitle		EQU	1<<ME_CenterTitleRF
ME_BigTitle		EQU	1<<ME_BigTitleRF
ME_BigText		EQU	1<<ME_BigTextRF
ME_CustomText		EQU	1<<ME_CustomTextRF
ME_ClearQuit		EQU	1<<ME_ClearQuitRF

; Form Flags
FO_ShowingRF		EQU	0
FO_InverseRF		EQU	1

FO_Showing		EQU	1<<FO_ShowingRF
FO_Inverse		EQU	1<<FO_InverseRF

; Label Flags
LA_BigFontRF		EQU	0
LA_InverseRF		EQU	1
LA_ShowingRF		EQU	2

LA_BigFont		EQU	1<<LA_BigFontRF
LA_Inverse		EQU	1<<LA_InverseRF
LA_Showing		EQU	1<<LA_ShowingRF

; Paragraph flags
PA_BigFontRF		EQU	0
PA_InverseRF		EQU	1
PA_CenteredRF		EQU	2
PA_ShowingRF		EQU	3

PA_BigFont		EQU	1<<PA_BigFontRF
PA_Inverse		EQU	1<<PA_InverseRF
PA_Centered		EQU	1<<PA_CenteredRF
PA_Showing		EQU	1<<PA_ShowingRF

; Button Flags
BU_BigFontRF		EQU	0
BU_InverseRF		EQU	1
BU_ShowingRF		EQU	2

BU_BigFont		EQU	1<<BU_BigFontRF
BU_Inverse		EQU	1<<BU_InverseRF
BU_Showing		EQU	1<<BU_ShowingRF

; Checkbox flags
CH_BigFontRF		EQU	0
CH_InverseRF		EQU	1
CH_BoxOnRightRF		EQU	2
CH_CheckedRF		EQU	3
CH_ShowingRF		EQU	4

CH_BigFont		EQU	1<<CH_BigFontRF
CH_Inverse		EQU	1<<CH_InverseRF
CH_BoxOnRight		EQU	1<<CH_BoxOnRightRF
CH_Checked		EQU	1<<CH_CheckedRF
CH_Showing		EQU	1<<CH_ShowingRF

; Options Flags
OP_BigFontRF		EQU	0
OP_InverseRF		EQU	1
OP_ShowingRF		EQU	2

OP_BigFont		EQU	1<<OP_BigFontRF
OP_Inverse		EQU	1<<OP_InverseRF
OP_Showing		EQU	1<<OP_ShowingRF

; TextBox Flags
TB_InverseRF		EQU	0
TB_NoBorderRF		EQU	1
TB_ShowingRF		EQU	2
TB_FocusableRF		EQU	3

TB_Inverse		EQU	1<<TB_InverseRF
TB_NoBorder		EQU	1<<TB_NoBorderRF
TB_Showing		EQU	1<<TB_ShowingRF
TB_Focusable		EQU	1<<TB_FocusableRF

; Bitmap Flags (Note the lack of RF flags here... just add)
BM_NoComp		EQU	0
BM_RLE			EQU	1
BM_VRLE			EQU	2

BM_Xor			EQU	0
BM_Or			EQU	4
BM_And			EQU	8
BM_Ld			EQU	12

; List Flags
LI_BigFontRF		EQU	0
LI_InverseRF		EQU	1
LI_CenteredRF		EQU	2
LI_NoBorderRF		EQU	3
LI_ShowingRF		EQU	4
LI_DroppedRF		EQU	5

LI_BigFont		EQU	1<<LI_BigFontRF
LI_Inverse		EQU	1<<LI_InverseRF
LI_Centered		EQU	1<<LI_CenteredRF
LI_NoBorder		EQU	1<<LI_NoBorderRF
LI_Showing		EQU	1<<LI_ShowingRF
LI_Dropped		EQU	1<<LI_DroppedRF

; DropList Flags
DL_BigFontRF		EQU	0
DL_InverseRF		EQU	1
DL_DropOnRRF		EQU	2
DL_ShowingRF		EQU	3

DL_BigFont		EQU	1<<DL_BigFontRF
DL_Inverse		EQU	1<<DL_InverseRF
DL_DropOnR		EQU	1<<DL_DropOnRRF
DL_Showing		EQU	1<<DL_ShowingRF

; ------ VARIABLES ------
; Do not modify any of these variables! They are for read-only use ONLY.
;
guiPage			EQU	814Fh		; Holds the flash page that GUI is on.
guiMouseX		EQU	8150h		; Col
guiMouseY		EQU	8151h		; Row
guiMouseKey		EQU	8152h		; Two previous directional keys (nibbles)
guiBkgdPtr		EQU	8153h ; 2 bytes   Used by mouse
guiDLPtr		EQU	8155h ; 2 bytes   Used to store pointer to Droplist when dropping
guiBkgd			EQU	8100h		; What's under the mouse



; ------ DATA TYPES ------
; These are used when creating forms to specify which type of object each is.
;
FormType		EQU	0
LabelType		EQU	3
ParaType		EQU	6
ButtonType		EQU	9
CheckBoxType		EQU	12
OptionsType		EQU	15
TextBoxType		EQU	18
BitmapType		EQU	21
ListType		EQU	24
DropListType		EQU	27

.list
.end